[Pkg-ocaml-maint-commits] [pcre-ocaml] 07/18: Imported Upstream version 7.1.6

Stéphane Glondu glondu at moszumanska.debian.org
Wed Aug 3 11:58:36 UTC 2016


This is an automated email from the git hooks/post-receive script.

glondu pushed a commit to branch master
in repository pcre-ocaml.

commit e50fde3b2c67d43f6da43752a84ac4bd6740aee8
Author: Stephane Glondu <steph at glondu.net>
Date:   Wed Aug 3 13:44:41 2016 +0200

    Imported Upstream version 7.1.6
---
 CHANGES.txt      |  2 ++
 _oasis           |  4 ++--
 lib/META         |  4 ++--
 lib/pcre.mli     |  7 +++++--
 lib/pcre_stubs.c | 16 ++++++++--------
 setup.ml         |  8 ++++----
 6 files changed, 23 insertions(+), 18 deletions(-)

diff --git a/CHANGES.txt b/CHANGES.txt
index 6ddfb1a..072bfc1 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -1,3 +1,5 @@
+2015-08-21:  Made GC less aggressive reclaiming regexps and chartables.
+
 2014-12-10:  Fixed another limit handling bug in the full_split function.
 
 2014-12-02:  Fixed a limit handling bug in the full_split function.
diff --git a/_oasis b/_oasis
index 307d67d..0488f46 100644
--- a/_oasis
+++ b/_oasis
@@ -1,10 +1,10 @@
 OASISFormat:      0.4
 Name:             pcre
-Version:          7.1.5
+Version:          7.1.6
 Synopsis:         pcre-ocaml - bindings to the Perl Compatibility Regular Expressions library
 Description:      pcre-ocaml offers library functions for string pattern matching and substitution, similar to the functionality offered by the Perl language.
 Authors:          Markus Mottl <markus.mottl at gmail.com>
-Copyrights:       (C) 1999-2014 Markus Mottl <markus.mottl at gmail.com>
+Copyrights:       (C) 1999-2015 Markus Mottl <markus.mottl at gmail.com>
 Maintainers:      Markus Mottl <markus.mottl at gmail.com>
 LicenseFile:      COPYING.txt
 License:          LGPL-2.1+ with OCaml linking exception
diff --git a/lib/META b/lib/META
index d72f31c..bb49166 100644
--- a/lib/META
+++ b/lib/META
@@ -1,6 +1,6 @@
 # OASIS_START
-# DO NOT EDIT (digest: 8ab62079b7fff0f9375c9ab7b6357cc5)
-version = "7.1.5"
+# DO NOT EDIT (digest: 46f60b1fadbd7e6335f389b0d4471def)
+version = "7.1.6"
 description =
 "pcre-ocaml - bindings to the Perl Compatibility Regular Expressions library"
 requires = "bytes"
diff --git a/lib/pcre.mli b/lib/pcre.mli
index 7f9fa44..723f517 100644
--- a/lib/pcre.mli
+++ b/lib/pcre.mli
@@ -57,8 +57,11 @@ exception Regexp_or of string * error
 
 (** {6 Compilation and runtime flags and their conversion functions} *)
 
-type icflag (** Internal representation of compilation flags *)
-and  irflag (** Internal representation of runtime flags *)
+(** Internal representation of compilation flags *)
+type icflag
+
+(** Internal representation of runtime flags *)
+and  irflag
 
 (** Compilation flags *)
 and cflag =
diff --git a/setup.ml b/setup.ml
index ff5aa91..340bf63 100644
--- a/setup.ml
+++ b/setup.ml
@@ -1,7 +1,7 @@
 (* setup.ml generated for the first time by OASIS v0.3.0 *)
 
 (* OASIS_START *)
-(* DO NOT EDIT (digest: d0d96be51aa08e29d7b4ceba3c0fefcc) *)
+(* DO NOT EDIT (digest: 9386999e3424345a63db8a4c91e5ae7d) *)
 (*
    Regenerated by OASIS v0.4.5
    Visit http://oasis.forge.ocamlcore.org for more information and
@@ -6683,7 +6683,7 @@ let setup_t =
           alpha_features = [];
           beta_features = [];
           name = "pcre";
-          version = "7.1.5";
+          version = "7.1.6";
           license =
             OASISLicense.DEP5License
               (OASISLicense.DEP5Unit
@@ -6694,7 +6694,7 @@ let setup_t =
                  });
           license_file = Some "COPYING.txt";
           copyrights =
-            ["(C) 1999-2014 Markus Mottl <markus.mottl at gmail.com>"];
+            ["(C) 1999-2015 Markus Mottl <markus.mottl at gmail.com>"];
           maintainers = ["Markus Mottl <markus.mottl at gmail.com>"];
           authors = ["Markus Mottl <markus.mottl at gmail.com>"];
           homepage = Some "http://mmottl.github.io/pcre-ocaml";
@@ -6982,7 +6982,7 @@ let setup_t =
        };
      oasis_fn = Some "_oasis";
      oasis_version = "0.4.5";
-     oasis_digest = Some "\031\003��=^\012J�c^9]��B";
+     oasis_digest = Some "�\146�\145\003bTN��J9<�Jc";
      oasis_exec = None;
      oasis_setup_args = [];
      setup_update = false

diff --git a/lib/pcre_stubs.c b/lib/pcre_stubs.c
index e2fd6eb..68702be 100644
--- a/lib/pcre_stubs.c
+++ b/lib/pcre_stubs.c
@@ -267,10 +267,10 @@ CAMLprim value pcre_compile_stub(value v_opt, value v_tables, value v_pat)
      could not be compiled */
   if (regexp == NULL) raise_bad_pattern(error, error_ofs);
 
-  /* Finalized value: GC will do a full cycle every 500 regexp allocations
-     (one regexp consumes in average probably less than 100 bytes ->
-     maximum of 50000 bytes unreclaimed regexps) */
-  v_rex = caml_alloc_final(4, pcre_dealloc_regexp, 100, 50000);
+  /* GC will do a full cycle every 1_000_000 regexp allocations (a typical
+     regexp probably consumes less than 100 bytes -> maximum of 100_000_000
+     bytes unreclaimed regexps) */
+  v_rex = caml_alloc_final(4, pcre_dealloc_regexp, 1, 1000000);
 
   /* Field[1]: compiled regular expression (Field[0] is finalizing
      function! See above!) */
@@ -631,10 +631,10 @@ CAMLprim value pcre_exec_stub_bc(value *argv, int __unused argn)
    page of PCRE */
 CAMLprim value pcre_maketables_stub(value __unused v_unit)
 {
-  /* GC will do a full cycle every 100 table set allocations
-     (one table set consumes 864 bytes -> maximum of 86400 bytes
-     unreclaimed table sets) */
-  const value v_res = caml_alloc_final(2, pcre_dealloc_tables, 864, 86400);
+  /* GC will do a full cycle every 1_000_000 table set allocations (one
+     table set consumes 864 bytes -> maximum of 864_000_000 bytes unreclaimed
+     table sets) */
+  const value v_res = caml_alloc_final(2, pcre_dealloc_tables, 1, 1000000);
   Field(v_res, 1) = (value) pcre_maketables();
   return v_res;
 }
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-ocaml-maint/packages/pcre-ocaml.git



More information about the Pkg-ocaml-maint-commits mailing list